import numpy as np


def multi_look(
    arr_in: np.ndarray,
    azimuth_looks: int,
    range_looks: int
) -> np.ndarray:
    '''Multi_look array with alks and rlks

    Parameters
    ----------
    arr_in: numpy.ndarray
        input array to be multi-looked
    azimuth_looks: int
        number of looks in azimuth
    range_looks: int
        number of looks in range
    '''
    pass
